==> cramr_ui_lib-1.0.16.tar.gz: test/widgets/cardinality_selection_panel_test.dart <==
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:cramr_ui_lib/widgets/cardinality_selection_panel.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final Finder singularSwitchFinder = find.byKey(const Key('singularToggle'));
final Finder pluralSwitchFinder = find.byKey(const Key('pluralToggle'));

main() async {
  testWidgets('check for presence of keys and toggling behaviour',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{
      'cardinality.singularEnabled': true,
      'cardinality.pluralEnabled': true
    });
    SharedPreferences prefs = await SharedPreferences.getInstance();
    var controller = SettingsController(
        SettingsService(prefs), ThemeMode.system, prefs, NotificationService());
    await controller.loadSettings();
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext context) {
          return controller.cardinalitySelection;
        },
        child: MaterialApp(
          home: CardinalitySelectionPanel(controller),
        )));

    expect(singularSwitchFinder, findsOneWidget);
    expect(pluralSwitchFinder, findsOneWidget);
    expect(true, (tester.widget(singularSwitchFinder) as Switch).value);
    expect(true, (tester.widget(pluralSwitchFinder) as Switch).value);
    await tester.tap(singularSwitchFinder);
    await tester.pumpAndSettle();
    expect(false, (tester.widget(singularSwitchFinder) as Switch).value);
    expect(true, (tester.widget(pluralSwitchFinder) as Switch).value);
    await tester.tap(pluralSwitchFinder);
    await tester.pumpAndSettle();
    expect(true, (tester.widget(singularSwitchFinder) as Switch).value);
    expect(false, (tester.widget(pluralSwitchFinder) as Switch).value);
  });

  testWidgets('test the manipulation of the dirty flag in the controller',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{
      'cardinality.singularEnabled': true,
      'cardinality.pluralEnabled': true
    });
    SharedPreferences prefs = await SharedPreferences.getInstance();
    var controller = SettingsController(
        SettingsService(prefs), ThemeMode.system, prefs, NotificationService());
    await controller.loadSettings();
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext context) {
          return controller.cardinalitySelection;
        },
        child: MaterialApp(
          home: CardinalitySelectionPanel(controller),
        )));

    expect(singularSwitchFinder, findsOneWidget);
    expect(pluralSwitchFinder, findsOneWidget);
    expect(true, (tester.widget(singularSwitchFinder) as Switch).value);
    expect(true, (tester.widget(pluralSwitchFinder) as Switch).value);
    await tester.tap(singularSwitchFinder);
    await tester.pumpAndSettle();
    expect(true, controller.cardinalitySelection.isDirty);
    await tester.tap(singularSwitchFinder);
    await tester.pumpAndSettle();
    expect(false, controller.cardinalitySelection.isDirty);
  });
}

==> cramr_ui_lib-2.0.0.tar.gz: test/widgets/cardinality_selection_panel_test.dart <==
import 'package:cramr_ui_lib/settings/client_context.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:cramr_ui_lib/widgets/cardinality_selection_panel.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final Finder singularSwitchFinder = find.byKey(const Key('singularToggle'));
final Finder pluralSwitchFinder = find.byKey(const Key('pluralToggle'));

main() async {
  testWidgets('check for presence of keys and toggling behaviour',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{
      'cardinality.singularEnabled': true,
      'cardinality.pluralEnabled': true
    });
    SharedPreferences prefs = await SharedPreferences.getInstance();
    var controller = SettingsController(
        SettingsService(prefs),
        ThemeMode.system,
        prefs,
        NotificationService(),
        ClientContext(ClientApp.verbomatiqueSecondaire));
    await controller.loadSettings();
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext context) {
          return controller.cardinalitySelection;
        },
        child: MaterialApp(
          home: CardinalitySelectionPanel(controller),
        )));

    expect(singularSwitchFinder, findsOneWidget);
    expect(pluralSwitchFinder, findsOneWidget);
    expect(true, (tester.widget(singularSwitchFinder) as Switch).value);
    expect(true, (tester.widget(pluralSwitchFinder) as Switch).value);
    await tester.tap(singularSwitchFinder);
    await tester.pumpAndSettle();
    expect(false, (tester.widget(singularSwitchFinder) as Switch).value);
    expect(true, (tester.widget(pluralSwitchFinder) as Switch).value);
    await tester.tap(pluralSwitchFinder);
    await tester.pumpAndSettle();
    expect(true, (tester.widget(singularSwitchFinder) as Switch).value);
    expect(false, (tester.widget(pluralSwitchFinder) as Switch).value);
  });

  testWidgets('test the manipulation of the dirty flag in the controller',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{
      'cardinality.singularEnabled': true,
      'cardinality.pluralEnabled': true
    });
    SharedPreferences prefs = await SharedPreferences.getInstance();
    var controller = SettingsController(
        SettingsService(prefs),
        ThemeMode.system,
        prefs,
        NotificationService(),
        ClientContext(ClientApp.verbomatiqueSecondaire));
    await controller.loadSettings();
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext context) {
          return controller.cardinalitySelection;
        },
        child: MaterialApp(
          home: CardinalitySelectionPanel(controller),
        )));

    expect(singularSwitchFinder, findsOneWidget);
    expect(pluralSwitchFinder, findsOneWidget);
    expect(true, (tester.widget(singularSwitchFinder) as Switch).value);
    expect(true, (tester.widget(pluralSwitchFinder) as Switch).value);
    await tester.tap(singularSwitchFinder);
    await tester.pumpAndSettle();
    expect(true, controller.cardinalitySelection.isDirty);
    await tester.tap(singularSwitchFinder);
    await tester.pumpAndSettle();
    expect(false, controller.cardinalitySelection.isDirty);
  });
}
